@@ -3,6 +3,8 @@ import matplotlib.style as _style
 import pkg_resources as _pkg
 import atexit as _atexit
 import cycler as _cycler
+import atlas_mpl_style.plot as plot
+import atlas_mpl_style.utils as utils
 
 _stylesheets = _pkg.resource_filename(__name__, "stylesheets")
 _atexit.register(_pkg.cleanup_resources)
@@ -144,15 +146,22 @@ def use_atlas_style(atlasLabel="ATLAS"):
     """
     global _atlas_label
     _style.use("atlas")
+    set_color_cycle("ATLAS")
     _atlas_label = atlasLabel
     _mpl.rcParams["font.size"] = 16
-    _mpl.rcParams["text.latex.preamble"] = [
-        r"\usepackage{helvet}",
-        r"\usepackage{sansmath}",
-        r"\setlength{\parindent}{0pt}" r"\sansmath",
+    _mpl.rcParams["xtick.minor.visible"] = True
+    _mpl.rcParams["ytick.minor.visible"] = True
+    _mpl.rcParams["text.latex.preamble"] = "\n".join([
+        r"\usepackage[LGR,T1]{fontenc}",
+        r"\usepackage{tgheros}",
+        r"\renewcommand{\familydefault}{\sfdefault}",
+        r"\usepackage{amsmath}",
+        r"\usepackage[symbolgreek,symbolmax]{mathastext}",
+        r"\usepackage{physics}",
+        r"\usepackage{siunitx}",
+        r"\setlength{\parindent}{0pt}",
         r"\def\mathdefault{}"
-    ]
-    _mpl.pyplot.minorticks_on()
+    ])
 
 
 def set_xlabel(label, ax=None, *args, **kwargs):
@@ -217,7 +226,7 @@ def draw_atlas_label(
         y position
     ax : mpl.axes.Axes, optional
         Axes to draw label in
-    status : [ *'int'* | 'wip' | 'prelim' | 'final' ], optional
+    status : [ *'int'* | 'wip' | 'prelim' | 'final' | 'opendata' ], optional
         Approval status
     simulation : bool (optional, default ``False``)
         Does the plot show only MC simulation results
@@ -243,6 +252,8 @@ def draw_atlas_label(
         status_str = "Work in Progress"
     elif status == "prelim":
         status_str = "Preliminary"
+    elif status == "opendata":
+        status_str = "Open Data"
     else:
         status_str = status
 
@@ -265,6 +276,7 @@ def draw_atlas_label(
     nl = r"\\"
     label = (
         fr'\textbf{{\textit{{{_atlas_label}}}}} {sim_str}{status_str}'
+        fr'{nl + "for education only" if status=="opendata" else ""}'
         fr'{nl if show_e_nl else ""}'
         fr'{energy_str}{lumi_str}{nl if desc_line else ""}'
         fr'{desc if desc_line else ""}'
